# Gutta - A Webcomic Static Site Builder

**gutta** is a framework to build static websites for webcomics, ready for hosting. It's especially suited to hosting on github.

Learn how to use gutta:

1. [Installation](docs/installation.md)
2. [Creating a new website and using gutta](docs/usage.md)
3. [Filling your website with content](docs/content.md)
4. [Styling your website](docs/styling.md)
5. [Publishing your website](docs/publishing.md)


